summaryrefslogtreecommitdiff
path: root/src/mongo/db/clientcursor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/clientcursor.h')
-rw-r--r--src/mongo/db/clientcursor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/clientcursor.h b/src/mongo/db/clientcursor.h
index 5e3803225fc..9ffe1ac1318 100644
--- a/src/mongo/db/clientcursor.h
+++ b/src/mongo/db/clientcursor.h
@@ -71,9 +71,9 @@ namespace mongo {
bool isAggCursor = false);
/**
* This ClientCursor is used to track sharding state.
*/
- ClientCursor(CursorManager* cursorManager);
+ explicit ClientCursor(const Collection* collection);
//
// Basic accessors
@@ -71,9 +71,9 @@ namespace mongo {
bool isAggCursor = false);
/**
- * This ClientCursor is used to track sharding state.
+ * This ClientCursor is used to track sharding state for the given collection.
*/